import hashlib

from django_migration_linter.utils import split_migration_path


class Migration(object):
    def __init__(self, abs_path):
        self.abs_path = abs_path
        self.app_name, self.name = split_migration_path(self.abs_path)

    def __lt__(self, other):
        if not isinstance(other, Migration):
            return NotImplemented
        return self.abs_path < other.abs_path

    def get_md5hash(self):
        hash_md5 = hashlib.md5()
        with open(self.abs_path, "rb") as f:
            for chunk in iter(lambda: f.read(4096), b""):
                hash_md5.update(chunk)
        return hash_md5.hexdigest()



# Copyright 2019 3YOURMIND GmbH

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

# http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from appdirs import user_cache_dir

__version__ = "0.1.5"

MIGRATION_FOLDER_NAME = "migrations"

DEFAULT_CACHE_PATH = user_cache_dir("django-migration-linter", version=__version__)
